pub struct IngestionClientArgs {
pub remote_store_url: Option<Url>,
pub remote_store_s3: Option<String>,
pub remote_store_gcs: Option<String>,
pub remote_store_azure: Option<String>,
pub local_ingestion_path: Option<PathBuf>,
pub rpc_api_url: Option<Url>,
pub rpc_username: Option<String>,
pub rpc_password: Option<String>,
pub checkpoint_timeout_ms: u64,
pub checkpoint_connection_timeout_ms: u64,
}Fields
remote_store_url: Option<Url>Remote Store to fetch checkpoints from over HTTP.
remote_store_s3: Option<String>Fetch checkpoints from AWS S3. Provide the bucket name or endpoint-and-bucket. (env: AWS_ENDPOINT, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, AWS_DEFAULT_REGION)
remote_store_gcs: Option<String>Fetch checkpoints from Google Cloud Storage. Provide the bucket name. (env: GOOGLE_SERVICE_ACCOUNT_PATH)
remote_store_azure: Option<String>Fetch checkpoints from Azure Blob Storage. Provide the container name. (env: AZURE_STORAGE_ACCOUNT_NAME, AZURE_STORAGE_ACCESS_KEY)
local_ingestion_path: Option<PathBuf>Path to the local ingestion directory.
rpc_api_url: Option<Url>Sui fullnode gRPC url to fetch checkpoints from.
rpc_username: Option<String>Optional username for the gRPC service.
rpc_password: Option<String>Optional password for the gRPC service.
checkpoint_timeout_ms: u64How long to wait for a checkpoint file to be downloaded (milliseconds). Set to 0 to disable the timeout.
checkpoint_connection_timeout_ms: u64How long to wait while establishing a connection to the checkpoint store (milliseconds). Set to 0 to disable the timeout.